==> jc-1.4.0.tar.gz: soot/jimple/parser/node/ANegUnop.h <==
// public final class soot.jimple.parser.node.ANegUnop

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6b18a5e7ed3d1a7a soot_jimple_parser_node_ANegUnop
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 33b1f5b96729d67a soot_jimple_parser_node_PUnop

// header file dependencies
// @dep_header soot_jimple_parser_node_PUnop

#include "soot/jimple/parser/node/PUnop.h"

#ifndef _JC_soot_jimple_parser_node_ANegUnop_H_
#define _JC_soot_jimple_parser_node_ANegUnop_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TNeg$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ANegUnop$sub_refs	_jc_soot_jimple_parser_node_ANegUnop$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ANegUnop$sub_nonrefs	_jc_soot_jimple_parser_node_ANegUnop$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ANegUnop$refs	_jc_soot_jimple_parser_node_ANegUnop$refs;
typedef struct _jc_soot_jimple_parser_node_ANegUnop$nonrefs	_jc_soot_jimple_parser_node_ANegUnop$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ANegUnop$object	_jc_soot_jimple_parser_node_ANegUnop$object;

typedef const struct _jc_soot_jimple_parser_node_ANegUnop$vmethods	_jc_soot_jimple_parser_node_ANegUnop$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ANegUnop$vtable	_jc_soot_jimple_parser_node_ANegUnop$vtable;
typedef const struct _jc_soot_jimple_parser_node_ANegUnop$vtype	_jc_soot_jimple_parser_node_ANegUnop$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ANegUnop$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ANegUnop$object *);
extern void _jc_soot_jimple_parser_node_ANegUnop$method$_init$cb20a16f4221eea4(_jc_env *, struct _jc_soot_jimple_parser_node_ANegUnop$object *, struct _jc_soot_jimple_parser_node_TNeg$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_ANegUnop$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ANegUnop$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ANegUnop$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ANegUnop$object *);
extern struct _jc_soot_jimple_parser_node_TNeg$object *_jc_soot_jimple_parser_node_ANegUnop$method$getNeg$5cd67f67ac62dc90(_jc_env *, struct _jc_soot_jimple_parser_node_ANegUnop$object *);
extern void _jc_soot_jimple_parser_node_ANegUnop$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ANegUnop$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ANegUnop$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ANegUnop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ANegUnop$method$setNeg$e693b9cbc6ecffa2(_jc_env *, struct _jc_soot_jimple_parser_node_ANegUnop$object *, struct _jc_soot_jimple_parser_node_TNeg$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ANegUnop$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ANegUnop$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ANegUnop$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ANegUnop$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ANegUnop$method_info$getNeg$5cd67f67ac62dc90;
extern _jc_method _jc_soot_jimple_parser_node_ANegUnop$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ANegUnop$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ANegUnop$method_info$setNeg$e693b9cbc6ecffa2;
extern _jc_method _jc_soot_jimple_parser_node_ANegUnop$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ANegUnop$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ANegUnop$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ANegUnop$object *);
	struct _jc_soot_jimple_parser_node_TNeg$object	*(*getNeg$5cd67f67ac62dc90)(_jc_env *, struct _jc_soot_jimple_parser_node_ANegUnop$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ANegUnop$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ANegUnop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setNeg$e693b9cbc6ecffa2)(_jc_env *, struct _jc_soot_jimple_parser_node_ANegUnop$object *, struct _jc_soot_jimple_parser_node_TNeg$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ANegUnop$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_ANegUnop$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PUnop$vmethods	soot_jimple_parser_node_PUnop;
	_jc_soot_jimple_parser_node_ANegUnop$vmethods	soot_jimple_parser_node_ANegUnop;
};

// Vtype
struct _jc_soot_jimple_parser_node_ANegUnop$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ANegUnop$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ANegUnop$sub_refs {
	struct _jc_soot_jimple_parser_node_TNeg$object	*__5fneg__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ANegUnop$refs {
    _jc_soot_jimple_parser_node_ANegUnop$sub_refs	soot_jimple_parser_node_ANegUnop;
    _jc_soot_jimple_parser_node_PUnop$sub_refs	soot_jimple_parser_node_PUnop;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ANegUnop$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ANegUnop$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PUnop$sub_nonrefs	soot_jimple_parser_node_PUnop;
    _jc_soot_jimple_parser_node_ANegUnop$sub_nonrefs	soot_jimple_parser_node_ANegUnop;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ANegUnop$object {
	_jc_soot_jimple_parser_node_ANegUnop$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ANegUnop$vtype	*vtype;
	_jc_soot_jimple_parser_node_ANegUnop$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ANegUnop$vtype _jc_soot_jimple_parser_node_ANegUnop$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ANegUnop, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ANegUnop$class_object;

#endif	/* _JC_soot_jimple_parser_node_ANegUnop_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/ANegUnop.h <==
// public final class soot.jimple.parser.node.ANegUnop

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 6b18a5e7ed3d1a7a soot_jimple_parser_node_ANegUnop
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 33b1f5b96729d67a soot_jimple_parser_node_PUnop

// header file dependencies
// @dep_header soot_jimple_parser_node_PUnop

#include "soot/jimple/parser/node/PUnop.h"

#ifndef _JC_soot_jimple_parser_node_ANegUnop_H_
#define _JC_soot_jimple_parser_node_ANegUnop_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TNeg$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ANegUnop$sub_refs	_jc_soot_jimple_parser_node_ANegUnop$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ANegUnop$sub_nonrefs	_jc_soot_jimple_parser_node_ANegUnop$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ANegUnop$refs	_jc_soot_jimple_parser_node_ANegUnop$refs;
typedef struct _jc_soot_jimple_parser_node_ANegUnop$nonrefs	_jc_soot_jimple_parser_node_ANegUnop$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ANegUnop$object	_jc_soot_jimple_parser_node_ANegUnop$object;

typedef const struct _jc_soot_jimple_parser_node_ANegUnop$vmethods	_jc_soot_jimple_parser_node_ANegUnop$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ANegUnop$vtable	_jc_soot_jimple_parser_node_ANegUnop$vtable;
typedef const struct _jc_soot_jimple_parser_node_ANegUnop$vtype	_jc_soot_jimple_parser_node_ANegUnop$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ANegUnop$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ANegUnop$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ANegUnop$method$_init$cb20a16f4221eea4(_jc_env *, struct _jc_soot_jimple_parser_node_ANegUnop$object *, struct _jc_soot_jimple_parser_node_TNeg$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_ANegUnop$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ANegUnop$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ANegUnop$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ANegUnop$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TNeg$object *_jc_soot_jimple_parser_node_ANegUnop$method$getNeg$5cd67f67ac62dc90(_jc_env *, struct _jc_soot_jimple_parser_node_ANegUnop$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ANegUnop$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ANegUnop$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ANegUnop$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ANegUnop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ANegUnop$method$setNeg$e693b9cbc6ecffa2(_jc_env *, struct _jc_soot_jimple_parser_node_ANegUnop$object *, struct _jc_soot_jimple_parser_node_TNeg$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ANegUnop$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ANegUnop$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ANegUnop$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ANegUnop$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ANegUnop$method_info$getNeg$5cd67f67ac62dc90;
extern _jc_method _jc_soot_jimple_parser_node_ANegUnop$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ANegUnop$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ANegUnop$method_info$setNeg$e693b9cbc6ecffa2;
extern _jc_method _jc_soot_jimple_parser_node_ANegUnop$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ANegUnop$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ANegUnop$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ANegUnop$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TNeg$object	*(*getNeg$5cd67f67ac62dc90)(_jc_env *, struct _jc_soot_jimple_parser_node_ANegUnop$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ANegUnop$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ANegUnop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setNeg$e693b9cbc6ecffa2)(_jc_env *, struct _jc_soot_jimple_parser_node_ANegUnop$object *, struct _jc_soot_jimple_parser_node_TNeg$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ANegUnop$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_ANegUnop$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PUnop$vmethods	soot_jimple_parser_node_PUnop;
	_jc_soot_jimple_parser_node_ANegUnop$vmethods	soot_jimple_parser_node_ANegUnop;
};

// Vtype
struct _jc_soot_jimple_parser_node_ANegUnop$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ANegUnop$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ANegUnop$sub_refs {
	struct _jc_soot_jimple_parser_node_TNeg$object	*__5fneg__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ANegUnop$refs {
    _jc_soot_jimple_parser_node_ANegUnop$sub_refs	soot_jimple_parser_node_ANegUnop;
    _jc_soot_jimple_parser_node_PUnop$sub_refs	soot_jimple_parser_node_PUnop;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ANegUnop$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ANegUnop$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PUnop$sub_nonrefs	soot_jimple_parser_node_PUnop;
    _jc_soot_jimple_parser_node_ANegUnop$sub_nonrefs	soot_jimple_parser_node_ANegUnop;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ANegUnop$object {
	_jc_soot_jimple_parser_node_ANegUnop$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ANegUnop$vtype	*vtype;
	_jc_soot_jimple_parser_node_ANegUnop$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ANegUnop$vtype _jc_soot_jimple_parser_node_ANegUnop$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ANegUnop, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ANegUnop$class_object;

#endif	/* _JC_soot_jimple_parser_node_ANegUnop_H_ */
